pub struct AnalyzeArgs {
pub file: String,
pub falsify: bool,
pub min_score: f64,
pub html: Option<String>,
pub json: bool,
}Expand description
Arguments for the analyze subcommand.
Fields
file: StringPTX file to analyze
falsify: boolRun full 100-point falsification framework.
The framework is always evaluated by analyze, so this flag is accepted
for backwards compatibility and does not currently change the output.
min_score: f64Fail if score < N
html: Option<String>Write HTML report to file
json: boolOutput JSON format