TokenKind

Enum TokenKind 

pub enum TokenKind {
Show 25 variants Eof, Directive, Entry, Func, Reg, Shared, Local, Global, Param, Identifier, Integer, Float, Instruction, Label, Comment, LBrace, RBrace, LParen, RParen, LBracket, RBracket, Comma, Semicolon, Colon, Unknown,
}
Token kinds for PTX lexing

Variants



Eof

End of file



Directive

.version, .target, .address_size, etc.



Entry

.entry keyword



Func

.func keyword



Reg

.reg declaration



Shared

.shared declaration



Local

.local declaration



Global

.global declaration



Param

.param declaration



Identifier

Identifier (register name, label, etc.)



Integer

Integer literal



Float

Float literal



Instruction

Instruction (ld, st, mov, add, etc.)



Label

Label (name:)



Comment

Comment (// or /* */)



LBrace

Opening brace {



RBrace

Closing brace }



LParen

Opening parenthesis (



RParen

Closing parenthesis )



LBracket

Opening bracket [



RBracket

Closing bracket ]



Comma

Comma ,



Semicolon

Semicolon ;



Colon

Colon :



Unknown

Unknown token