Modifier

Enum Modifier 

pub enum Modifier {
Show 23 variants Shared, Global, Local, Const, Param, U32, U64, S32, S64, F32, F64, B32, B64, Sync, Cta, Gl, Sys, AtomicAdd, AtomicCas, AtomicExch, AtomicMin, AtomicMax, Other(String),
}
Instruction modifiers

Variants



Shared

.shared



Global

.global



Local

.local



Const

.const



Param

.param



U32

.u32



U64

.u64



S32

.s32



S64

.s64



F32

.f32



F64

.f64



B32

.b32



B64

.b64



Sync

.sync



Cta

.cta



Gl

.gl



Sys

.sys



AtomicAdd

.add (atomic add)



AtomicCas

.cas (compare and swap)



AtomicExch

.exch (exchange)



AtomicMin

.min



AtomicMax

.max



Other(String)

Other modifier

Implementations

Source

impl Modifier

pub fn as_address_space(&self) -> Option<AddressSpace>

Get the address space if this is an address space modifier

pub fn as_type(&self) -> Option<PtxType>

Get the type if this is a type modifier